OC.L10N.register(
    "settings",
    {
    "Private" : "Soukromé",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Viditelné pouze lidem, se kterými nalezena shoda začleněním přes telefonní číslo prostřednictvím Talk na mobilním telefonu",
    "Local" : "Místní",
    "Only visible to people on this instance and guests" : "Viditelné pouze lidem na této instanci a hostům",
    "Federated" : "Federované",
    "Only synchronize to trusted servers" : "Synchronizovat pouze s důvěryhodnými servery",
    "Published" : "Zveřejněno",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizovat s důvěryhodnými servery a globálním a veřejným adresářem kontaktů",
    "Verify" : "Ověřit",
    "Verifying …" : "Ověřování…",
    "Unable to change password" : "Heslo nejde změnit",
    "Very weak password" : "Velmi snadno prolomitelné heslo",
    "Weak password" : "Snadno prolomitelné heslo",
    "So-so password" : "Ještě použitelné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Odolné heslo",
    "Groups" : "Skupiny",
    "Group list is empty" : "Seznam skupin je prázdný.",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
    "{actor} added you to group {group}" : "{actor} vás přidal(a) do skupiny {group}",
    "You added {user} to group {group}" : "Přidali jste {user} do skupiny {group}",
    "{actor} added {user} to group {group}" : "{actor} přidal(a) {user} do skupiny {group}",
    "An administrator added you to group {group}" : "Správce vás přidal do skupiny {group}",
    "An administrator added {user} to group {group}" : "Správce přidal {user} do skupiny {group}",
    "{actor} removed you from group {group}" : "{actor} vás odebral(a) ze skupiny {group}",
    "You removed {user} from group {group}" : "Odebrali jste {user} ze skupiny {group}",
    "{actor} removed {user} from group {group}" : "{actor} odebral(a) {user} ze skupiny {group}",
    "An administrator removed you from group {group}" : "Správce vás odebral ze skupiny {group}",
    "An administrator removed {user} from group {group}" : "Správce odebral {user} ze skupiny {group}",
    "Your <strong>group memberships</strong> were modified" : "Vaše <strong>členství ve skupinách</strong> byla upravena",
    "{actor} changed your password" : "{actor} změnil(a) vaše heslo",
    "You changed your password" : "Změnili jste si své heslo",
    "Your password was reset by an administrator" : "Vaše heslo bylo resetováno správcem",
    "Your password was reset" : "Vaše heslo bylo nastaveno znovu",
    "{actor} changed your email address" : "{actor} změnil(a) vaši e-mailovou adresu",
    "You changed your email address" : "Změnili jste si svou e-mailovou adresu",
    "Your email address was changed by an administrator" : "Vaše e-mailová adresa byla změněna správcem",
    "You created an app password for a session named \"{token}\"" : "Vytvořili jste heslo pro aplikaci pro relaci nazvanou „{token}“",
    "An administrator created an app password for a session named \"{token}\"" : "Správce vytvořil heslo pro aplikaci pro relaci nazvanou „{token}",
    "You deleted app password \"{token}\"" : "Smazali jste heslo pro aplikaci „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Přejmenovali jste heslo aplikace „{token}“ na „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Udělili jste přístup k souborovému systému aplikaci, používající heslo „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Zrušili jste přístup k souborovému systému pro aplikaci, využívající heslo „{token}“",
    "Security" : "Zabezpečení",
    "You successfully logged in using two-factor authentication (%1$s)" : "Úspěšně jste se přihlásili pomocí dvoufázového ověření (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o přihlášení s použitím dvoufázové autentizace se nezdařil (%1$s)",
    "Remote wipe was started on %1$s" : "Vymazání na dálku spuštěno na %1$s",
    "Remote wipe has finished on %1$s" : "Vymazání na dálku bylo na %1$s dokončeno",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> nebo <strong>e-mail</strong> bylo změněno",
    "Settings" : "Nastavení",
    "Could not remove app." : "Aplikaci se nedaří odebrat.",
    "Could not update app." : "Aplikaci se nedaří aktualizovat.",
    "Wrong password" : "Nesprávné heslo",
    "Unable to change personal password" : "Osobní heslo se nedaří změnit",
    "Saved" : "Uloženo",
    "No Login supplied" : "Nezadáno žádné přihlašovací jméno",
    "Unable to change password. Password too long." : "Heslo se nedaří změnit – je příliš dlouhé.",
    "Authentication error" : "Chyba přihlášení",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Zadejte správcovské heslo pro obnovu, jinak budou veškerá data účtu ztracena.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné heslo správce pro obnovu. Překontrolujte správnost jeho zadání a zkuste to znovu.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Podpůrná vrstva nepodporuje změnu hesla, ale šifrovací klíč účtu byl aktualizován.",
    "Administrator documentation" : "Dokumentace pro správce",
    "User documentation" : "Dokumentace pro uživatele",
    "Nextcloud help overview" : "Přehled nápovědy k Nextcloud",
    "Invalid SMTP password." : "Neplatné heslo pro SMTP.",
    "Email setting test" : "Zkouška nastavení e-mailu",
    "Well done, %s!" : "Úspěšně nastaveno, %s!",
    "If you received this email, the email configuration seems to be correct." : "Pokud přišel tento e-mail, nastavení pro odesílání e-mailů se zdá být v pořádku.",
    "Email could not be sent. Check your mail server log" : "E-mail se nepodařilo odeslat. Podívejte se do záznamu událostí (log) svého e-mailového serveru.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Při odesílání e-mailu nastala chyba – překontrolujte nastavení. (Chyba: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Aby bylo možné odesílat zkušební e-maily je třeba, abyste si nejprve u svého účtu nastavili svou e-mailovou adresu. To učiníte v %s.",
    "Recently active" : "Nedávno aktivní",
    "Disabled accounts" : "Zakázané účty",
    "Invalid account" : "Neplatný účet",
    "Invalid mail address" : "Neplatná e-mailová adresa",
    "Settings saved" : "Nastavení uložena",
    "Unable to change full name" : "Nedaří se změnit celé jméno",
    "Unable to change email address" : "Nepodařilo se změnit e-mailovou adresu",
    "Unable to set invalid phone number" : "Do nastavení zadáno neplatné telefonní číslo",
    "Unable to set invalid website" : "Nelze nastavit neplatnou webovou stránku",
    "Some account data was invalid" : "Některé údaje v účtu nejsou platné",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pokud chcete ověřit váš Twitter účet, napište následující tweet (ujistěte se, že ho zasíláte bez zalomení řádků):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pro ověřování vašich webových stránek uložte následující obsah v kořenovém adresáři webové prezentace v umístění „.well-known/CloudIdVerificationCode.txt“ (ujistěte se, že byl text vložen jako jediný řádek)",
    "%1$s changed your password on %2$s." : "%1$s změnil(a) vaše heslo na %2$s.",
    "Your password on %s was changed." : "Vaše heslo na %s bylo změněno.",
    "Your password on %s was reset by an administrator." : "Vaše heslo na %s bylo resetováno správcem.",
    "Your password on %s was reset." : "Vaše heslo na %s bylo nastaveno znovu.",
    "Password for %1$s changed on %2$s" : "Heslo pro %1$s na %2$s změněno ",
    "Password changed for %s" : "Heslo změněno pro %s",
    "If you did not request this, please contact an administrator." : "Pokud jste o toto nežádali, obraťte se na správce.",
    "Your email address on %s was changed." : "Vaše e-mailová adresa na %s byla změněna.",
    "Your email address on %s was changed by an administrator." : "Vaše e-mailová adresa na %s byla změněna správcem.",
    "Email address for %1$s changed on %2$s" : "E-mailová adresa pro %1$s se na %2$s změnila",
    "Email address changed for %s" : "E-mailová adresa pro %s byla změněna",
    "The new email address is %s" : "Nová e-mailová adresa je %s",
    "Your %s account was created" : "Váš %s účet byl vytvořen",
    "Welcome aboard" : "Vítejte na palubě",
    "Welcome aboard %s" : "Vítejte na palubě, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Vítejte ve svém %s účtu, můžete vkládat, chránit a sdílet svoje data.",
    "Your Login is: %s" : "Vaše přihlašovací jméno je: %s",
    "Set your password" : "Nastavte si své heslo",
    "Go to %s" : "Jít na %s",
    "Install Client" : "Nainstalovat klienta",
    "Logged in account must be a sub admin" : "Je třeba, aby přihlášený účet byl dílčím správcem",
    "Apps" : "Aplikace",
    "Personal" : "Osobní",
    "Administration" : "Správa",
    "Users" : "Uživatelé",
    "Additional settings" : "Další nastavení",
    "Assistant" : "Asistent",
    "Administration privileges" : "Oprávnění ke správě",
    "Groupware" : "Software pro podporu spolupráce",
    "Overview" : "Přehled",
    "Basic settings" : "Základní nastavení",
    "Sharing" : "Sdílení",
    "Availability" : "Dostupnost",
    "Calendar" : "Kalendář",
    "Personal info" : "Osobní údaje",
    "Mobile & desktop" : "Mobilní a desktop",
    "Artificial Intelligence" : "Umělá inteligence",
    "Email server" : "E-mailový server",
    "Mail Providers" : "Poskytovatelé e-mailů",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Poskytovatelé e-mailů umožňují odesílání e-mailů přímo prostřednictvím osobního e-mailového účtu uživatele. Zatím je tato funkce omezena na pozvánky do kalendáře. Vyžaduje Nextcloud E-mail 4.1 a účet v Nextcloud E-mail, který se shoduje s e-mailovou adresou uživatele v Nextcloud.",
    "Send emails using" : "Posílat e-maily pomocí",
    "User's email account" : "Uživatelova e-mailového účtu",
    "System email account" : "Systémového e-mailového účtu",
    "Security & setup checks" : "Kontroly zabezpečení a nastavení",
    "Background jobs" : "Úlohy na pozadí",
    "Unlimited" : "Neomezeně",
    "Verifying" : "Ověřuje se",
    "Allowed admin IP ranges" : "Rozsahy IP adres, ze kterých je možné provádět správu",
    "Admin IP filtering isn't applied." : "Filtrování IP adres pro správu není uplatněno.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Klíč nastavení „%1$s“ očekává pole (namísto toho nalezeno%2$s). Ověřování IP rozsahu pro správu nebude uplatňováno. ",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Klíč nastavení „%1$s“ obsahuje neplatný IP rozsah(y): „%2$s“",
    "Admin IP filtering is correctly configured." : "Filtrování IP adres pro správu je nastaveno správně.",
    "App directories owner" : "Vlastník adresářů aplikace",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Složky některých aplikací jsou vlastněny jiným uživatelem, než je ten webového serveru. To může být případ pokud aplikace byly nainstalované ručně. Zkontrolujte oprávnění následujících složek aplikací:\n%s",
    "App directories have the correct owner \"%s\"" : "Složky aplikací mají správného vlastníka „%s“",
    "Brute-force Throttle" : "Přiškrcování útoků hrubou silou",
    "Your remote address could not be determined." : "Nepodařilo se zjistit vaši vzdálenou adresu.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Vaše vzdálená adresa byla identifikována jako „%s“ a rychlost vyřizování požadavků z ní je v tuto chvíli omezována kvůli zamezení přetěžování útokem hádání hesel (bruteforce). Pokud vzdálená adresa není vaše, může se jednat o indikaci, že není správně nastavena proxy.",
    "Your remote address \"%s\" is not brute-force throttled." : "Vaše vzdálená adresa „%s“ není omezena z důvodu ochrany proti útokům hrubou silou.",
    "Old administration imported certificates" : "Staré správou naimportované certifikáty",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Úloha na pozadí čeká na kontrolu správou naimportovaných SSL certifikátů. Zkuste to prosím později.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Nacházejí se zde některé SSL certifikáty, naimportované správou, které se už s Nextcloud 21 nepoužívají. Lze je naimportovat v příkazovém řádku pomocí příkazu „occ security:certificates:import“. Popisy jejich umístění v adresáři s daty jsou uvedeny níže.",
    "Code integrity" : "Neporušenost kódu",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Nástroj pro kontrolu neporušenosti byl vypnut. Neporušenost proto není možné ověřit.",
    "No altered files" : "Žádné pozměněné soubory",
    "Some files have not passed the integrity check. {link1} {link2}" : "Některé soubory neprošly kontrolou neporušennosti. {link1} {link2}",
    "Cron errors" : "Chyby plánovače",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Nebylo možné spustit službu plánovače cron v CLI. Došlo k následujícím technickým chybám:\n%s",
    "The last cron job ran without errors." : "Nejnovější naplánovaná úloha proběhla bez problémů.",
    "Cron last run" : "Nejnovější spuštění plánovače (cron)",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Poslední vykonání úlohy na pozadí bylo %s. Něco se zdá být špatného. {link}.",
    "Last background job execution ran %s." : "Poslední vykonání úlohy na pozadí bylo %s.",
    "Data directory protected" : "Adresář s daty chráněn",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš datový adresář a soubory jsou pravděpodobně přístupné z Internetu. Soubor .htaccess nefunguje. Je důrazně doporučeno nastavit váš webový server tak, aby  tento adresář už nebyl dostupný z Internetu, nebo byl přesunut mimo prostor, zpřístupňovaný webovým serverem.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nepodařilo se zkontrolovat, zda je adresář s daty chráněn. Zkontrolujte ručně, že váš server neumožňuje přístup do adresáře s daty.",
    "Database missing columns" : "V databázi chybí sloupce",
    "Missing optional column \"%s\" in table \"%s\"." : "Chybí volitelný sloupec „%s“ v tabulce „%s“.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V databázi chybí některé volitelné sloupce. Protože přidání sloupců do rozsáhlých tabulek může trvat dlouho, nebyly přidány automaticky (jsou volitelné). Spuštěním příkazu „occ db:add-missing-columns“ je možné tyto chybějící sloupce přidat ručně a to za provozu instance. Po přidání se může zlepšit doba reakce a použitelnost některých funkcí.",
    "Database missing indices" : "V databázi chybí indexy",
    "Missing indices:" : "Chybějící rejstříky:",
    "\"%s\" in table \"%s\"" : "„%s“ v tabulce „%s“",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Zjištěny některé chybějící volitelné indexy. Nové indexy jsou průběžně přidávány (do Nextcloudu nebo instalovaných aplikací) pro zlepšení výkonu databáze. Vytváření indexů může dočasně snížit výkon systému a proto nejsou indexy vytvářeny automaticky během aktualizací. Jakmile jsou indexy vytvořeny, databázové operace by měly být rychlejší. K vytvoření chybějících indexů použijte příkaz `occ db:add-missing-indices`. ",
    "Database missing primary keys" : "V databázi chybí primární klíče",
    "Missing primary key on table \"%s\"." : "Chybí primární klíč v tabulce „%s“.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V databázi chybí některé primární klíče. Vzhledem k tomu, že přidání primárních klíčů do velkých tabulek může nějakou dobu trvat, nebyly přidány automaticky. Spuštěním příkazu „occ db:add-missing-primary-keys“ lze tyto chybějící primární klíče přidat ručně, zatímco instance běží.",
    "Database pending bigint migrations" : "V databázi jsou čekající předělání na datové typy bigint (dlouhá celá čísla)",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "U některých sloupců tabulek databáze doposud nebyla provedena konverze na datový typ big int. To proto, že změna typů sloupců ve velkých tabulkách může trvat dlouho a proto nebylo provedeno automaticky. Provedení je možné spustit ručně a to spuštěním příkazu „occ db: convert-filecache-bigint“. Ovšem provést lze jen tehdy, když je instance Nexcloud odstavená.",
    "Debug mode" : "Režim ladění",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Tato instance je spuštěná v ladicím režimu. Toto zapínejte pouze pro lokální vývoj a nikoli v produkčních prostředích.",
    "Debug mode is disabled." : "Ladící režim je vypnutý.",
    "Default phone region" : "Výchozí mezinárodní předčíslí",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Vaše instalace nemá nastavenou žádnou výchozí oblast telefonu. To je nutné k ověření telefonních čísel v nastavení profilu bez kódu země. Chcete-li povolit čísla bez kódu země, přidejte do svého souboru s nastaveními řetězec „default_phone_region“ s příslušným kódem ISO 3166-1 regionu.",
    "Email test" : "Zkouška e-mailu",
    "Mail delivery is disabled by instance config \"%s\"." : "Doručení e-mailu je vypnuto v nastavení instance „%s“.",
    "Email test was successfully sent" : "Testovací e-mail byl úspěšně odeslán",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Doposud jste nenastavili či neověřili jste nastavení pro e-mailový server. Přejděte do „Základních nastavení“ a nastavte je. Poté použijte tlačítko „Odeslat e-mail“ níže ve formuláři a svá nastavení ověřte.",
    "Transactional File Locking" : "Transakční zamykání souborů",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transakční zamykání souborů je vypnuté. Toto není podporované nastavení. Může vést k obtížně izolovatelným problémům včetně poškozování souborů. Odeberte položku nastavení `'filelocking.enabled' => false` ze svého `config.php`  a vyhněte se tak problémům.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Databáze je používaná pro transakční zamykání souborů. Pokud chcete vylepšit výkon, nastavte memcache (pokud je k dispozici).",
    "Forwarded for headers" : "Přeposláno pro hlavičky",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Nastavení „trusted_proxies není provedeno správně – mělo by být polem.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Vaše nastavení „trusted_proxies“ není nastaveno správně. Mělo by být polem IP adres – volitelně rozsah v CIDR zápisu.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavení pro hlavičku reverzní proxy není správné. Toto je problém v zabezpečení a mohlo by umožnit útočníkům podvrhnout jejich IP adresu jako viditelnou pro Nextcloud.",
    "Your IP address was resolved as %s" : "Vaše IP adresa byla přeložena jako %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavení hlaviček reverzní proxy není správné nebo přistupujete na Nextcloud z důvěryhodné proxy. Pokud nepřistupujete k Nextcloud z důvěryhodné proxy, potom je toto bezpečností chyba a může útočníkovi umožnit falšovat IP adresu, kterou NextCloud vidí.",
    "HTTPS access and URLs" : "HTTPS přístup a URL adresy",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Přistupujete přes přes nezabezpečený HTTP protokol. Důrazně doporučujeme nastavit svůj server tak, aby namísto toho vyžadoval HTTPS. Bez šifrovaného spojení nebudou k dispozici některé důležité funkce, jako např. „zkopírovat do schránky“ nebo tzv. „service workers“!",
    "Accessing site insecurely via HTTP." : "Nezabezpečený přístup k webu přes HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "K vámi využívané instanci sice přistupujete přes zabezpečené připojení, nicméně tato vytváří nezabezpečené URL adresy. To s nejvyšší pravděpodobností znamená, že se nachází za reverzní proxy a hodnoty nastavení Nextcloud `overwrite*` nejsou nastavené správně.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Vaše instance vytváří nezabezpečené URL adresy. Pokud k ní přistupujete přes HTTPs, pak to nejspíš znamená, že se nachází za reverzní proxy a hodnoty nastavení Nextcloud `overwrite*` nejsou nastavené správně.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "K vámi využívané instanci přistupujete přes zabezpečené spojení a ta vytváří bezpečné URL adresy.",
    "Internet connectivity" : "Připojení k internetu",
    "Internet connectivity is disabled in configuration file." : "Připojení k Internetu je vypnuté v souboru s nastaveními.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Tento server nemá funkční připojení k Internetu: Nedaří se připojit k vícero koncovým bodům. Některé moduly jako např. externí úložiště, upozorňování na dostupnost aktualizací, nebo instalace aplikací třetích stran kvůli tomu nebudou fungovat. Přístup k souborům z jiných míst a odesílání e-mailů s upozorněními také nemusí fungovat. Pokud chcete využívat všechny možnosti tohoto serveru, doporučujeme zprovoznit připojení k Internetu.",
    "JavaScript modules support" : "Podpora JavaScript modulů",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Nepodařilo se spustit kontrolu ohledně podpory pro JavaScript. Prosím napravte to ručně nebo ručně potvrďte, zda váš webový server poskytuje soubory `.mjs` pomocí MIME typu JavaScript.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Váš webový server neposkytuje soubory `.mjs` pomocí MIME typu JavaScript. Toto rozbíjí některé aplikace tím, že prohlížečům brání ve spouštění JavaScript souborů. Měli byste svůj webový server nastavit tak, aby soubory `.mjs` poskytoval s MIME typem buď `text/javascript` nebo `application/javascript` .",
    "JavaScript source map support" : "Podpora JavaScript zdrojových map",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Váš webový server není nastavený tak, aby poskytoval soubory `.js.map`. Bez nich nebudou správně fungovat zdrojové mapy JavaScriptu, což ztíží řešení problémů a ladění jakéhokoli problému, který může nastat. ",
    "Old server-side-encryption" : "Původní šifrování na straně serveru",
    "Disabled" : "Vypnuto",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Je zapnutý starý formát šifrování na straně serveru. Je doporučeno toto vypnout.",
    "Logging level" : "Stupeň podrobností zaznamenávání událostí",
    "The %1$s configuration option must be a valid integer value." : "Je třeba, aby předvolba nastavení %1$s bylo platné celé číslo.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Stupeň podrobnosti zaznamenávání událostí je nastavený na ladění. To používejte pouze pokud máte problémy, které diagnostikujete a poté stupeň podrobnosti vraťte na nějaký méně výřečný, protože to vytváří opravdu mnoho informací a může negativně ovlivnit výkon serveru.",
    "Logging level configured correctly." : "Stupeň podrobnosti zaznamenávání událostí nastaven správně.",
    "Maintenance window start" : "Začátek doby údržby",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Na serveru není nastavený žádný začátek doby údržby. To znamená, že každodenní na systémové prostředky náročné úlohy na pozadí budou spouštěné také v průběhu běžného uživatelského provozu. Doporučujeme nastavit na dobu nízkého využívání, čímž se vytěžování těmito náročnými úlohami bude méně dotýkat uživatelů.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Okno pro údržbu, ve kterém vykonávat náročné úlohy na pozadí je mezi {start}:00 UTC a {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Coby distribuovaná mezipaměť je nastaveno Memcached, ale je nainstalován nesprávný PHP modul („memcache“). Nainstalujte správný PHP modul „memcached“.",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Coby distribuovaná mezipaměť je nastaveno Memcached, ale potřebný PHP modul – „memcached“ – není nainstalován. Prosíme napravte to.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Nebylo nastaveno žádné ukládání do mezipaměti. Pokud chcete vylepšit výkon, nastavte memcache (pokud je k dispozici).",
    "Failed to write and read a value from local cache." : "Nepodařilo se zapsat a načíst hodnotu z místní mezipaměti.",
    "Failed to write and read a value from distributed cache." : "Nepodařilo se zapsat a načíst hodnotu z distribuované mezipaměti.",
    "Configured" : "Nastaveno",
    "Mimetype migrations available" : "Migraci mimetypů k dispozici",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Je k dispozici jedna nebo více migrací mimetypu. Občas jsou přidány nové mimetypy pro lepší obsloužení určitých typů souborů. Na velkých instancích zabere migrace mimetypů dlouhou dobu, proto se neprovádí automaticky při aktualizacích. Pro provedení migrací použijte příkaz `occ maintenance:repair --include-expensive`.",
    "MySQL row format" : "Formát řádku v MySQL",
    "You are not using MySQL" : "Nepoužíváte MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Žádná z tabulek nepoužívá ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "V databázi nalezen nesprávný formát řádků. ROW_FORMAT=Dynamic poskytuje nejlepší výkon databáze pro Nextcloud. Aktualizujte formát řádků na následujícím seznamu: %s.",
    "MySQL Unicode support" : "Podpora MySQL Unicode",
    "MySQL is used as database and does support 4-byte characters" : "Jako databáze je používáno MySQL a nepodporuje 4bajtové znaky",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "Jako databáze je používána MySQL, ale nepodporuje 4 bajtové znaky. Aby bylo možné takové znaky (jako například emotikony) v názvech souborů nebo komentářích zobrazit, je doporučeno zapnout podporu 4 bajtových znaků v MySQL.",
    "OCS provider resolving" : "Překlad OCS poskytovatele",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Nepodařilo se zkontrolovat zda váš webový server správně překládá URL adresy OCM a OCS poskytovatele.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Tento webový server není správně nastaven pro rozpoznání %1$s.\nTo nejspíše souvisí s nastavením webového serveru, které nebylo upraveno tak, aby jej dovedlo přímo do této složky.\nPorovnejte svou konfiguraci s dodávanými rewrite pravidly v „.htaccess“ pro Apache nebo těm poskytnutým v dokumentaci pro Nginx.\nU Nginx jsou to obvykle řádky začínající na „location ~“, které potřebují úpravu.",
    "Overwrite CLI URL" : "Přepsat URL CLI",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "Volba „overwrite.cli.url“ ve vašem config.php je správně nastavená na „%s“.",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "Volba „overwrite.cli.url“ ve vašem config.php je nastavená na „%s“, což je správná URL. Doporučená URL je „%s“.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Zajistěte, aby volba „overwrite.cli.url„ v souboru config.php byla nastavena na URL adresu, přes kterou uživatelé přistupují k této instanci Nextcloud. Doporučení: „%s“. Pokud tomu tak nebude, může docházet k problémům při vytváření URL prostřednictvím plánovače cron. (ačkoli je možné, že doporučená URL není tou, kterou uživatelé zpravidla používají pro přístup k této instanci Nextcloud. Nejlepší je toto v každém případě překontrolovat.)",
    "PHP APCu configuration" : "Nastavení PHP APC",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Došlo k naplnění APCu mezipaměti – zvažte její navýšení v php nastavení apc.shm_size",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "APC mezipaměť je už skoro plná, na %s%% – zvažte její navýšení v php nastavení apc.shm_size",
    "PHP default charset" : "Výchozí znaková sada pro PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "Volba nastavení PHP „default_charset“ by měla být UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funkce je k dispozici",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP funkce „set_time_limit“ není dostupná. To může způsobit ukončení skriptů uprostřed provádění a další problémy s instalací. Doporučujeme tuto funkci povolit.",
    "Freetype" : "Freetype",
    "Supported" : "Podporováno",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vámi využívaná verze PHP nepodporuje FreeType, což bude mít za následky vizuální nedostatky u obrázků profilů a v rozhraní pro nastavování.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Zdá se, že PHP není správně nastaveno pro dotazování proměnných prostředí systému. Test s příkazem getenv(\"PATH\") vrátí pouze prázdnou odpověď.",
    "PHP file size upload limit" : "PHP limit velikosti nahrávaných souborů",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP upload_max_filesize je příliš nízké. Je doporučena velikost přinejmenším %1$s. Stávající hodnota: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP post_max_size je příliš nízké. Je doporučena velikost přinejmenším %1$s. Stávající hodnota: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP max_input_time je příliš nízké. Je doporučena velikost přinejmenším %1$s. Stávající hodnota: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP max_execution_time je příliš nízké. Je doporučena velikost přinejmenším %1$s. Stávající hodnota: %2$s.",
    "PHP memory limit" : "PHP limit paměti",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "Limit paměti pro PHP je nižší než doporučená hodnota %s. Některé funkce či aplikace – včetně nástroje pro aktualizaci – nemusí správně fungovat.",
    "PHP modules" : "PHP moduly",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "Zvyšuje rychlost překladu jazyka a opravuje řazení znaků mimo ASCII",
    "for Argon2 for password hashing" : "pro tvorbu otisků hesla Argon2",
    "required for SFTP storage and recommended for WebAuthn performance" : "vyžadováno pro SFTP úložiště a doporučeno pro výkon WebAuthn",
    "for picture rotation in server and metadata extraction in the Photos app" : "pro otáčení obrázku na serveru a získávání metadat v aplikaci Fotky",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Tato instance postrádá některé potřebné PHP moduly. Je třeba je nainstalovat: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Této instanci chybí některé doporučené moduly pro PHP. V zájmu lepšího výkonu a kompatibility, je důrazně doporučeno je nainstalovat:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP modul OPcache není načten. Pro lepší výkon je doporučeno načíst ho do vaší PHP instalace.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache je vypnuté. Pro lepší výkon je doporučeno mít v nastavení PHP „opcache.enable=1“.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "OPcache založené na sdílené paměti je vypnuté. Pro lepší výkon je doporučeno mít v nastavení PHP „opcache.file_cache_only=0“ a používat souborovou mezipaměť až jako druhý stupeň mezipaměti.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache nefunguje, jak by mělo, opcache_get_status() vrací negaci (false) – zkontrolujte nastavení.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu „opcache.max_accelerated_files“ s hodnotou vyšší než „%s“.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "Vyrovnávací paměť OPcache je téměř zaplněná. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu „opcache.memory_consumption“ s hodnotou vyšší než „%s“.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "Vnitřní vyrovnávací paměť OPcache pro řetězce je téměř zaplněná. Aby bylo zajištěno, že ukládání řetězců do mezipaměti bude skutečně prováděno, je doporučeno přidat do nastavení PHP volbu „opcache.interned_strings_buffer“ s hodnotou vyšší než „%s“.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache je nastaveno tak, aby odebíralo komentáře kódu. Pokud je OPcache zapnuté, pak aby Nextcloud fungoval, je třeba, aby bylo nastaveno také „opcache.save_comments=1“.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Pro Nextcloud nemáte zpřístupněno používání aplikačního program. rozhraní (API) OPcache. Pokud je OPcache zapnuté, je velmi doporučováno zahrnout veškeré složky s Nextcloud do „opcache.restrict_api“ nebo toto nastavení zrušit a vypnout tak omezení k OPcache API. Zabráníte tak chybám při aktualizacím jádra Nextcloud či aplikací.",
    "Checking from CLI, OPcache checks have been skipped." : "Kontroluje se z CLI – kontroly OPcache byly přeskočeny.",
    "The PHP OPcache module is not properly configured. %s." : "PHP modul OPcache není správně nastavený: %s.",
    "Correctly configured" : "Správně nastaveno",
    "PHP version" : "Verze PHP",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Nyní  provozujete na PHP %1$s. Od Nextcloud %3$s je PHP %2$s už označeno jako zastaralé. Nextcloud %4$s pak už může vyžadovat alespoň PHP %5$s. Co možná nejdříve přejděte na některou z oficiálně podporovaných verzí PHP, poskytovaných PHP Group.",
    "You are currently running PHP %s." : "Nyní provozujete na PHP %s.",
    "PHP \"output_buffering\" option" : "Volba PHP „output_buffering“",
    "PHP configuration option \"output_buffering\" must be disabled" : "Je třeba aby volba nastavení PHP „output_buffering byla vypnutá",
    "Push service" : "Služba push",
    "Valid enterprise license" : "Platná licence pro podniky",
    "Free push service" : "Push služba zdarma",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Toto je nepodporované komunitní sestavení Nextcloud. Vzhledem k velikosti této instance, není garantován výkon, spolehlivost, ani škálovatelnost. Aby se zabránilo přetěžování našich služeb, které jsou zdarma, okamžitá oznámení jsou omezena. Zjistěte více o výhodách Nextcloud pro podniky na {link}.",
    "Random generator" : "Generátor náhodnosti",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP nenalezlo žádný použitelný zdroj náhodnosti a to je velmi nedoporučováno z bezpečnostních důvodů.",
    "Secure" : "Zabezpečené",
    "Configuration file access rights" : "Přístupová práva na soubor s nastaveními",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Nastavení bylo přepnuto do režimu pouze pro čtení. To brání   změnám prostřednictvím webového rozhraní. Dále při každé aktualizaci, je třeba soubor ručně zpřístupnit pro zápis.",
    "Nextcloud configuration file is writable" : "Do souboru s nastaveními pro Nextcloud lze zapisovat",
    "Scheduling objects table size" : "Velikost tabulky objektů plánování",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Máte více než %s řádků v tabulce objektů plánování. Prosím spusťte na výkon náročné opravné úlohy pomocí occ maintenance:repair --include-expensive.",
    "Scheduling objects table size is within acceptable range." : "Velikost tabulky objektů plánování je v přijatelném rozsahu.",
    "HTTP headers" : "HTTP hlavičky",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP hlavička `%1$s` není nastavena na `%2$s`. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP hlavička `%1$s` není nastavena na `%2$s`. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP hlavička `%1$s` není nastavena na `%2$s`, `%3$s`, `%4$s`, `%5$s` nebo `%6$s`. Kvůli tomu může uniknout referer údaj. Podrobnosti viz {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- HTTP hlavička `Strict-Transport-Security` není nastavena na hodnotu alespoň `%d` sekund (stávající hodnota: `%d`). Pro zlepšení zabezpečení je doporučeno použít dlouhou zásadu HSTS.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP hlavička `Strict-Transport-Security` HTTP nemá správnou podobu: `%s`. Pro zlepšení zabezpečení je doporučeno zapnout HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- HTTP hlavička `Strict-Transport-Security` není nastavena (mělo by být alespoň `%d` sekund). Pro zlepšení zabezpečení je doporučeno HSTS zapnout.",
    "Some headers are not set correctly on your instance" : "Některé hlavičky nejsou ve vaší instanci správně nastaveny",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Nepodařilo se zkontrolovat že vámi využívaný webový server je správně nastaven tak, aby správně poskytoval hlavičky zabezpečení. Zkontrolujte to ručně.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Nepodařilo se zkontrolovat zda vámi využívaný webový server je správně nastaven tak, aby správně poskytoval hlavičky zabezpečení – nepodařil ose dotázat `%s`",
    "Your server is correctly configured to send security headers." : "Server je správně nastaven pro odesílání hlaviček zabezpečení",
    "Database version" : "Verze databáze",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zjištěna verze MariaDB 10.3 – tuto verzi už její vývojáři nepodporují (existuje ještě podpora coby součásti Ubuntu 20.04) Pro nejlepší výkon, stabilitu a funkčnost s touto verzí Nextcloud je doporučeno MariaDB >=%1$s a <=%2$s.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zjištěna verze MariaDB „%1$s“. Pro nejlepší výkon, stabilitu a funkčnost s touto verzí Nextcloud je doporučeno MariaDB >=%2$s a <=%3$s.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zjištěna verze MySQL „%1$s“. Pro nejlepší výkon, stabilitu a funkčnost s touto verzí Nextcloud je doporučeno MySQL >=%2$s a <=%3$s.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zjištěna verze PostgreSQL „%1$s“. Pro nejlepší výkon, stabilitu a funkčnost s touto verzí Nextcloud je doporučeno PostgreSQL >=%2$s a <=%3$s.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "Coby databáze je nyní využíváno SQLite. V případě vícero uživatelů a/nebo množství dat doporučujeme přejít na robustnější databázi. Zejména je toto doporučeno v případě synchronizace souborů prostřednictvím klienta pro počítač. Na jinou databázi je možné přejít pomocí nástroje pro příkazový řádek: „occ db:convert-type“.",
    "Unknown database platform" : "Neznámá databázová platforma",
    "Architecture" : "Architektura",
    "64-bit" : "64bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Zdá se, že provozujete 32bitovou verzi PHP. Aby správně fungoval, potřebuje Nextcloud 64bit. Přejděte na 64bit instalaci operačního systému a PHP!",
    "Task Processing pickup speed" : "Rychlost vyzvedávání zpracovávání úkolů",
    "_No scheduled tasks in the last %n hour._::_No scheduled tasks in the last %n hours._" : ["Žádné naplánované úkoly v uplynulé %n hodině.","Žádné naplánované úkoly v uplynulých %n hodinách.","Žádné naplánované úkoly v uplynulých %n hodinách.","Žádné naplánované úkoly v uplynulých %n hodinách."],
    "_The task pickup speed has been ok in the last %n hour._::_The task pickup speed has been ok in the last %n hours._" : ["Rychlost vyzvedávání úkolů byla ok za uplynulou %n hodinu.","Rychlost vyzvedávání úkolů byla ok za uplynulých %n hodin.","Rychlost vyzvedávání úkolů byla ok za uplynulých %n hodin.","Rychlost vyzvedávání úkolů byla ok za uplynulých %n hodin."],
    "_The task pickup speed has been slow in the last %n hour. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n hours. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Rychlost vyzvedávání byla nízká za uplynulou %n hodinu. U mnoha úkolů trvalo více než 4 minuty, než byly vyzvednuty. Zvažte nastavení zpracovávajícího procesu na pozadí.","Rychlost vyzvedávání byla nízká za uplynulé %n hodiny. U mnoha úkolů trvalo více než 4 minuty, než byly vyzvednuty. Zvažte nastavení zpracovávajícího procesu na pozadí.","Rychlost vyzvedávání byla nízká za uplynulých %n hodin. U mnoha úkolů trvalo více než 4 minuty, než byly vyzvednuty. Zvažte nastavení zpracovávajícího procesu na pozadí.","Rychlost vyzvedávání byla nízká za uplynulé %n hodiny. U mnoha úkolů trvalo více než 4 minuty, než byly vyzvednuty. Zvažte nastavení zpracovávajícího procesu na pozadí."],
    "Temporary space available" : "Dočasný prostor k dispozici",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Chyba při kontrole popisu umístění dočasných souborů PHP – nebylo správně nastaveno na složku. Vrácená hodnota: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funkce „disk_free_space“ je vypnutá, což brání v kontrolách zda je k dispozici dostatek místa ve složkách pro dočasná data.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Chyba při zjišťování dostupného prostoru na úložišti v popisu umístění dočasných souborů pro PHP, případně vráceno že není žádné volné místo. Popis umístění pro dočasné soubory: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB k dispozici v %s (složka pro dočasná data PHP)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB k dispozici v %s (složka pro dočasná data Nextcloud)",
    "Temporary directory is correctly configured:\n%s" : "Dočasná složka je správně nastavena:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Tato instance využívá jako hlavní úložiště objektové úložiště založené na S3 a má dostatek prostoru v dočasné složce.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Tato instance používá jako hlavní úložiště objektové úložiště, založené na protokolu S3. Nahrané soubory jsou dočasně ukládány na server a proto je doporučeno mít 50 GiB volného prostoru v adresáři temp pro PHP. Podrobnosti o umístění a prostoru, který je k dispozici naleznete v záznamu událostí. Pro navýšení kapacit nasměrujte v php.ini na jiný adresář nebo zvyšte kapacitu stávajícího umístění.\nKontrolou dostupného prostoru v umístění pro dočasná data bylo zjištěno %.1f GiB namísto doporučených 50 GiB. Popis umístění: %s",
    "Database transaction isolation level" : "Stupeň izolace databázových transakcí",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaše databáze není spuštěná s úrovní izolace transakcí „READ COMMITTED“. Toto může způsobit problémy při paralelním spouštění více akcí současně.",
    "Was not able to get transaction isolation level: %s" : "Nebylo možné získat stupeň izolace databázových transakcí: %s",
    ".well-known URLs" : ".well-known URLs",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` je ve vašem nastavení vypnuto (false), takže tato kontrola byla přeskočena.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Nepodařilo se zkontrolovat že vámi využívaný webový server je správně nastaven tak, aby správně poskytoval `.well-known` . Zkontrolujte to ručně.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Tento webový server není správně nastaven pro překlad `.well-known` URL adres. Chybující URL je `%s`.",
    "Your server is correctly configured to serve `.well-known` URLs." : "Server je správně nastaven poskytování `.well-known` URL adres.",
    "Font file loading" : "Načítání souboru s písmem",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Nepodařilo se zkontrolovat podporu načítání {extension}. Zkontrolujte ručně, zda vámi využívaný webový server poskytuje `.{extension}` soubory.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Váš webový server není správně nastaven k doručování .{extension} souborů. To je obvykle chyba v nastavení Nginx. Nextcloud 15 také potřebuje úpravu k doručování .{extension} souborů. Porovnejte své nastavení Nginx s doporučeným nastavením v naší dokumentaci.",
    "Profile information" : "Informace o profilu",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilový obrázek, celé jméno, e-mailová adresa, telefonní číslo, adresa, webové stránky, Twitter, organizace, role, úvod, životopis a to, zda je profil zapnutý",
    "Nextcloud settings" : "Nastavení Nextcloud",
    "Unified task processing" : "Sjednocené zpracovávání úkolů",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Úlohy AI je možné implementovat různými aplikacemi. Zde je možné nastavit, která z nich má být používána který typ úlohy.",
    "Allow AI usage for guest users" : "Umožnit uživatelům-hostům využívat AI",
    "Enable" : "Zapnout",
    "None of your currently installed apps provide Task processing functionality" : "Žádná z v tuto chvíli nainstalovaných aplikací neposkytuje funkci zpracovávání úkolů",
    "Machine translation" : "Strojový překlad",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Strojový překlad je možné implementovat různými aplikacemi. Zde je možné definovat pořadí přednosti aplikací pro strojový překlad, které máte v tuto chvíli nainstalované.",
    "Image generation" : "Vytváření obrázků",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Vytváření obrázků je možné implementovat různými aplikacemi. Zde je možné nastavit, která z nich má být používána.",
    "None of your currently installed apps provide image generation functionality" : "Žádná z v tuto chvíli nainstalovaných aplikací neposkytuje funkci vytváření obrázků",
    "Text processing" : "Zpracování textu",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Úlohy zpracovávání textu je možné implementovat různými aplikacemi. Zde je možné nastavit, která z nich má být používána který typ úlohy.",
    "Task:" : "Úloha:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Žádná z v tuto chvíli nainstalovaných aplikací neposkytuje funkci zpracovávání textu prostřednictvím API rozhraní pro zpracovávání textu.",
    "Here you can decide which group can access certain sections of the administration settings." : "Zde je možné rozhodnout, které skupiny mohou přistupovat k určitým nastavením správy.",
    "Unable to modify setting" : "Nastavení se nedaří změnit",
    "None" : "Žádné",
    "Changed disclaimer text" : "Změnit text ohledně zřeknutí se odpovědnosti",
    "Deleted disclaimer text" : "Smazat text ohledně zřeknutí se zodpovědnosti",
    "Could not set disclaimer text" : "Nepodařilo se nastavit text ohledně zřeknutí se odpovědnosti",
    "Allow apps to use the Share API" : "Umožnit aplikacím používat aplikační program. rozhraní (API) pro práci se sdíleními",
    "Allow resharing" : "Povolit příjemcům tohoto sdílení, aby sami mohli sdílet dalším",
    "Allow sharing with groups" : "Povolit sdílení se skupinami",
    "Restrict users to only share with users in their groups" : "Povolit sdílení pouze mezi uživateli v rámci skupiny",
    "Ignore the following groups when checking group membership" : "Při kontrole členství ve skupinách ignorovat následující skupiny",
    "Allow users to preview files even if download is disabled" : "Umožnit uživatelům zobrazovat si náhledy souborů, i když je jejich stahování znepřístupněno",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Uživatelé i tak budou moci pořizovat snímky/video z obrazovky. Neposkytuje to jakoukoli definitivní ochranu.",
    "Allow users to share via link and emails" : "Povolit uživatelům sdílet pomocí odkazů a e-mailů",
    "Allow public uploads" : "Povolit veřejné nahrávání souborů",
    "Allow public shares to be added to other clouds by federation." : "Umožnit přidávání veřejných sdílení do ostatních cloudů prostřednictvím federování.",
    "This will add share permissions to all newly created link shares." : "Toto přidá oprávnění ke sdílení ke všem nově vytvářeným sdílením odkazem.",
    "Always ask for a password" : "Vždy se zeptat na heslo",
    "Enforce password protection" : "Vynutit ochranu heslem",
    "Exclude groups from password requirements" : "Z požadavků na heslo vynechat následující skupiny",
    "Exclude groups from creating link shares" : "Vyjmout skupiny z možnosti vytváření sdílení odkazem",
    "Allow users to set custom share link tokens" : "Umožnit uživatelům nastavovat své vlastní tokeny odkazů sdílení",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Sdílení s uživatelsky určenými tokeny zůstanou přístupné i v případě vypnutí tohoto nastavení",
    "Shares with guessable tokens may be accessed easily" : "Sílení s uhodnutelnými tokeny mohou být snadno přístupná",
    "Limit sharing based on groups" : "Omezit sdílení na základě skupin",
    "Allow sharing for everyone (default)" : "Povolit sdílení všem (výchozí)",
    "Exclude some groups from sharing" : "Vyjmout vybrané skupiny ze sdílení",
    "Limit sharing to some groups" : "Povolit sdílení jen vybraným skupinám",
    "Groups allowed to share" : "Skupiny, které mohou sdílet",
    "Groups excluded from sharing" : "Skupiny vyloučené ze sdílení",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Vyloučené skupiny budou mít nadále možnost přijímat nabídky ke sdílení, ale nebudou je moci zasílat.",
    "Set default expiration date for internal shares" : "Nastavit výchozí datum skončení platností pro interní sdílení",
    "Enforce expiration date" : "Vynutit datum skončení platnosti",
    "Default expiration time of new shares in days" : "Výchozí doba platnosti nových sdílení (dny)",
    "Expire shares after x days" : "Ukončit platnost sdílení po X dnech",
    "Set default expiration date for shares to other servers" : "Nastavit výchozí datum skončení platnosti pro sdílení na jiné servery",
    "Enforce expiration date for remote shares" : "Vynutit datum skončení platnosti pro vzdálená sdílení",
    "Default expiration time of remote shares in days" : "Výchozí doba platnosti vzdálených sdílení (dny)",
    "Expire remote shares after x days" : "Ukončit platnost vzdálených sdílení po X dnech",
    "Set default expiration date for shares via link or mail" : "Nastavit výchozí datum skončení platnosti pro sdílení prostřednictvím odkazu nebo e-mailu",
    "Default expiration time of shares in days" : "Výchozí doba platnosti  sdílení (dny)",
    "Privacy settings for sharing" : "Nastavení soukromí pro sdílení",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Povolit automatické doplňování názvu účtu v dialogu sdílení a umožnit přístup k systémovému adresáři kontaktů",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "V případě, že jsou zapnuté automatická dokončování „stejná skupina“ a „začlenění telefonním číslem“, postačí pro zobrazení uživatele shoda s jedním z toho.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Omezit automatické doplňování názvu účtu a přístup k adresáři kontaktů na uživatele ve stejných skupinách",
    "Restrict account name autocompletion to users based on phone number integration" : "Omezit doplňování názvu účtu uživatelům na základě začlenění telefonním číslem",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Povolit automatické dokončování při zadávání celého jména nebo e-mailové adresy (při ignorování chybějící shody s telefonním seznamem a toho, že je ve stejné skupině)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zobrazit text zřeknutí se odpovědnosti na stránce pro nahrání veřejného odkazu. (zobrazit pouze pokud je seznam souborů skrytý)",
    "Disclaimer text" : "Text ohledně zřeknutí se odpovědnosti",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tento text bude zobrazen on stránce pro nahrání veřejného odkazu, pokud bude seznam souborů skrytý.",
    "Default share permissions" : "Výchozí oprávnění sdílení",
    "Two-Factor Authentication" : "Dvoufázové ověření",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvoufázové ověřování je možné vynutit pro všechny účty a konkrétní skupiny. Pokud nemají nastaveného poskytovatele dvoufázového ověřování, nebudou se moci přihlásit do systému.",
    "Enforce two-factor authentication" : "Vynutit dvoufázové ověřování",
    "Limit to groups" : "Omezit na skupiny",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vynucení dvoufázového ověřování je možné nastavit pouze pro určité skupiny.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvoufázové ověřování je vynucováno pro všechny členy následujících skupin.",
    "Enforced groups" : "Vynucené skupiny",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvoufázové ověřování není vynucováno pro členy následujících skupin.",
    "Excluded groups" : "Vynechané skupiny",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Když jsou skupiny vybrány/vynechány, je pro zjišťování zda je účtu vynuceno dvoufázové (2FA) ověřování použita následující logika: Pokud nejsou vybrány žádné skupiny, je 2FA zapnuto pro všechny kromě členů vynechaných skupin. Pokud jsou nějaké skupiny vybrány, je 2FA zapnuto pro všechny jejich členy. Pokud je účet členem jak vybrané, tak vynechané skupiny, pak má ta vybraná přednost a 2FA je vynuceno.",
    "Save changes" : "Uložit změny",
    "Default" : "Výchozí",
    "Registered Deploy daemons list" : "Seznam zaregistrovaných procesů nasazování",
    "No Deploy daemons configured" : "Nejsou nastavené žádné procesy služby nasazování",
    "Register a custom one or setup from available templates" : "Zaregistrujte uživatelsky určené nebo nastavte z dostupných šablon",
    "Show details for {appName} app" : "Zobrazit podrobnosti o aplikaci {appName}",
    "Update to {update}" : "Aktualizovat na {update}",
    "Remove" : "Odstranit",
    "Featured" : "Doporučené",
    "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného podpory Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Doporučované aplikace jsou vyvíjeny komunitou. Jsou propojeny se zbytkem Nextcloud a připraveny na produkční nasazení.",
    "Community rating: {score}/5" : "Hodnocení komunitou: {score}/5",
    "Disable all" : "Zakázat vše",
    "Download and enable all" : "Stáhnout a zapnout vše",
    "All apps are up-to-date." : "Všechny aplikace jsou aktuální",
    "Icon" : "Ikona",
    "Name" : "Název",
    "Version" : "Verze",
    "Level" : "Stupeň podrobnosti/závažnosti",
    "Actions" : "Akce",
    "Results from other categories" : "Výsledky z ostatních kategorií",
    "No apps found for your version" : "Nenalezeny žádné aplikace pro vámi využívanou verzi",
    "_%n app has an update available_::_%n apps have an update available_" : ["Pro %n aplikaci je k dispozici aktualizace","Pro %n aplikace jsou k dispozici aktualizace","Pro %n aplikací jsou k dispozici aktualizace","Pro %n aplikace jsou k dispozici aktualizace"],
    "_Update_::_Update all_" : ["Aktualizovat","Aktualizovat vše","Aktualizovat vše","Aktualizovat vše"],
    "Failed to load groups" : "Nepodařilo se načíst skupiny",
    "Failed to create group" : "Skupinu se nepodařilo vytvořit",
    "Creating group…" : "Vytváření skupiny…",
    "Create group" : "Vytvořit skupinu",
    "Group name" : "Název skupiny",
    "Please enter a valid group name" : "Zadejte platný název pro skupinu",
    "Search groups…" : "Hledat skupiny…",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Seznam skupin. Není vykreslen celý z důvodu nároků na výkon. Skupiny budou načítány, jak se budete posouvat seznamem nebo ho prohledávat.",
    "Loading groups…" : "Načítání skupin…",
    "Could not load app discover section" : "Nepodařilo se načíst sekci objevování aplikací",
    "Could not render element" : "Prvek se nepodařilo vykreslit",
    "Nothing to show" : "Není co zobrazit",
    "Could not load section content from app store." : "Nepodařilo se načíst obsah sekce z katalogu aplikací.",
    "Loading" : "Načítání",
    "Fetching the latest news…" : "Získávání nejnovějších zpráv…",
    "Carousel" : "Kolotoč",
    "Previous slide" : "Předchozí snímek",
    "Next slide" : "Následující snímek",
    "Choose slide to display" : "Zvolte snímek který zobrazit",
    "{index} of {total}" : "{index} z {total}",
    "Daemon" : "Proces služby",
    "Deploy Daemon" : "Nasadit proces služby",
    "Type" : "Typ",
    "Display Name" : "Zobrazované jméno",
    "GPUs support" : "Podpora pro výpočty na GPU",
    "Compute device" : "Výpočetní zařízení",
    "Advanced deploy options" : "Pokročilé předvolby pro nasazení",
    "Edit ExApp deploy options before installation" : "Předvolby nasazení ExApp před instalací",
    "Configured ExApp deploy options. Can be set only during installation" : "Nastavené předvolby nasazení ExAPP. Je možné nastavovat pouze při instalaci",
    "Learn more" : "Zjistit více",
    "Environment variables" : "Proměnné prostředí",
    "ExApp container environment variables" : "Proměnné prostředí pro kontejner s ExApp",
    "No environment variables defined" : "Nedefinovány žádné proměnné prostředí",
    "Mounts" : "Připojení",
    "Define host folder mounts to bind to the ExApp container" : "Definovat připojení hostitelské složky pro napojení na kontejner s ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Je třeba, aby existovalo na hostiteli procesu nasazovací služby ještě před instalací ExApp",
    "Host path" : "Popis umístění hostitele",
    "Container path" : "Popis umístění kontejneru",
    "Read-only" : "Pouze pro čtení",
    "Remove mount" : "Odebrat připojení",
    "New mount" : "Nové připojení",
    "Enter path to host folder" : "Zadejte popis umístění složky hostitele",
    "Enter path to container folder" : "Zadejte popis umístění složky kontejneru",
    "Toggle read-only mode" : "Vyp/zap. režim pouze pro čtení",
    "Confirm adding new mount" : "Potvrďte přidání nového připojení",
    "Confirm" : "Potvrdit",
    "Cancel adding mount" : "Zrušit přidávání připojení",
    "Cancel" : "Storno",
    "Add mount" : "Přidat připojení",
    "ExApp container mounts" : "Připojení kontejneru s ExApp",
    "No mounts defined" : "Nedefinována žádná připojení",
    "Description" : "Popis",
    "View in store" : "Zobrazit v katalogu aplikací",
    "Visit website" : "Navštívit webovou stránku",
    "Usage documentation" : "Dokumentace k používání",
    "Admin documentation" : "Dokumentace pro správce",
    "Developer documentation" : "Dokumentace pro vývojáře",
    "Details" : "Podrobnosti",
    "All" : "Vše",
    "Limit app usage to groups" : "Omezit používání aplikace na skupiny",
    "No results" : "Žádné výsledky",
    "Update to {version}" : "Aktualizovat na {version}",
    "Deploy options" : "Předvolby nasazení",
    "Default Deploy daemon is not accessible" : "Výchozí proces služby nasazování není dostupný",
    "Delete data on remove" : "Při odebrání smazat data",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavený žádný požadavek na minimální verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavenou žádnou nejvyšší podporovanou verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "Latest updated" : "Naposledy aktualizováno",
    "Author" : "Autor",
    "Categories" : "Kategorie",
    "Resources" : "Prostředky",
    "Documentation" : "Dokumentace",
    "Interact" : "Interakce",
    "Report a bug" : "Nahlásit chybu",
    "Request feature" : "Požádat o přidání funkce",
    "Ask questions or discuss" : "Položit dotaz či diskutovat",
    "Rate the app" : "Ohodnotit aplikaci",
    "Rate" : "Hodnotit",
    "Changelog" : "Souhrn změn",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "{productName} iOS app" : "{productName} aplikace pro iOS",
    "{productName} Android app" : "{productName} aplikace pro Android",
    "{productName} Talk for iOS" : "{productName} Talk pro iOS",
    "{productName} Talk for Android" : "{productName} Talk pro Android",
    "Sync client" : "Synchronizační klient",
    "This session" : "Toto sezení",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Název zařízení",
    "Cancel renaming" : "Zrušit přejmenovávání",
    "Save new name" : "Uložit nový název",
    "Marked for remote wipe" : "Označeno k vymazání obsahu na dálku",
    "Device settings" : "Nastavení zařízení",
    "Allow filesystem access" : "Povolit přístup k souborovému systému",
    "Rename" : "Přejmenovat",
    "Revoke" : "Odvolat",
    "Wipe device" : "Vymazat obsah zařízení",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Odvolání platnosti tohoto tokenu může zabránit vymazání obsahu zařízení, pokud proces vymazání ještě nebyl do teď zahájen.",
    "Device" : "Zařízení",
    "Last activity" : "Poslední aktivita",
    "Devices & sessions" : "Zařízení a sezení",
    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví a mobilní klienti aktuálně přihlášení k vašemu účtu.",
    "Error while creating device token" : "Chyba při vytváření tokenu zařízení",
    "App name" : "Název aplikace",
    "Create new app password" : "Vytvořit nové heslo aplikace",
    "App password copied!" : "Heslo pro aplikaci zkopírováno!",
    "Copy app password" : "Zkopírovat heslo pro aplikaci",
    "Login name copied!" : "Přihlašovací jméno zkopírováno!",
    "Copy login name" : "Zkopírovat přihlašovací jméno",
    "Could not copy app password. Please copy it manually." : "Nedaří se zkopírovat heslo pro aplikaci. Zkopírujte ho ručně.",
    "Could not copy login name. Please copy it manually." : "Přihlašovací jméno se nepodařilo zkopírovat. Zkopírujte ho ručně.",
    "New app password" : "Nové heslo pro aplikaci",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Níže uvedené přihlašovací údaje použijte pro nastavení své aplikace či zařízení. Z bezpečnostních důvodů bude toto heslo zobrazeno jen jednou.",
    "Login" : "Přihlásit",
    "Password" : "Heslo",
    "Show QR code for mobile apps" : "Zobrazit QR kód pro mobilní aplikace",
    "Use system cron service to call the cron.php file every 5 minutes." : "Použít systémový plánovač (cron) pro volání souboru cron.php každých 5 minut.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Je třeba, aby cron.php bylo spouštěno s právy systémového účtu „{user}“.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Je zapotřebí rozšíření PHP pro POSIX. Podrobnosti viz {linkstart}dokumentace k PHP{linkend}.",
    "Unable to update background job mode" : "Nedaří se aktualizovat režim úlohy běžící na pozadí",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Pro správnou funkci serveru je důležité správně nastavit úlohy spouštěné na pozadí. Doporučenou metodou je použití systémového plánovače (cron). Další informace naleznete v dokumentaci.",
    "Last job execution ran {time}. Something seems wrong." : "Minulé vykonání úlohy bylo {time}. Zdá se, že něco není v pořádku.",
    "Last job ran {relativeTime}." : "Poslední úloha proběhla {relativeTime}.",
    "Background job did not run yet!" : "Úloha na pozadí ještě nebyla spuštěná!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Vykonat jednu úlohu při každém načtení stránky. Příklad použití: instance pro jeden účet.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php je zaregistrován u služby webcron aby přes HTTP volala cron.php každých 5 minut. Příklad použití: velmi malá instance (1-5 účtů, v závislosti na vytížení).",
    "Cron (Recommended)" : "Cron (doporučeno)",
    "Unable to update profile default setting" : "Nedaří se aktualizovat výchozí nastavení pro profily",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Profily nově vytvářených účtů ve výchozím stavu zpřístupňovat nebo nezpřístupňovat.",
    "Password confirmation is required" : "Je vyžadováno potvrzení hesla",
    "Failed to save setting" : "Nastavení se nepodařilo uložit",
    "{app}'s declarative setting field: {name}" : "Kolonka deklarativního nastavení {app}: {name}",
    "Unable to update server side encryption config" : "Nedaří se zaktualizovat nastavení šifrování na straně serveru",
    "Server-side encryption" : "Šifrování na straně serveru",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifrování na straně serveru umožňuje zašifrovat soubory, které jsou na tento server nahrávány. To přináší omezení jako třeba snížení výkonu, takže toto zapněte jen pokud je opravdu potřeba.",
    "To encrypt all existing files run this OCC command:" : "Pro zašifrování veškerých existujících souborů spusťte tento OCC příkaz:",
    "Enable server-side encryption" : "Šifrovat na straně serveru",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Vypnutí šifrování na straně serveru je možné pouze pomocí OCC (nahlédněte do dokumentace).",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenačten žádný šifrovací modul – zapněte ho v nabídce aplikace.",
    "Select default encryption module:" : "Vyberte výchozí šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Zapněte „Výchozí modul šifrování“ a spusťte příkaz {command}",
    "Cancel encryption" : "Zrušit šifrování",
    "Enable encryption" : "Šifrovat",
    "Confirm enabling encryption" : "Potvrďte zapnutí šifrování",
    "Please read carefully before activating server-side encryption:" : "Důkladně si pročtěte a až teprve poté případně zapínejte šifrování dat na straně serveru:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Poté co je zapnuto šifrování, jsou od toho bodu všechny nahrávané soubory šifrovány serverem. Vypnout šifrování bude možné pouze později, až bude šifrovací modul tuto možnost podporovat a po splnění všech nutných podmínek (tzn. nastavení klíčů pro obnovení).",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Ve výchozím stavu bude vytvořen hlavní klíč pro celou instanci. Zkontrolujte zda je takový stupeň přístupu v souladu s vašimi potřebami.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrování samotné ještě nezaručuje bezpečnost systému. Pokud se chcete dozvědět víc o tom, jak aplikace pro šifrování funguje a jaké jsou podporované případy použití, naleznete to v dokumentaci.",
    "Be aware that encryption always increases the file size." : "Mějte na paměti, že šifrování vždy navýší velikost souboru.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je vždy dobré vytvářet pravidelné zálohy svých dat. V případě zapnutého šifrování také společně s daty zajistěte zálohu šifrovacích klíčů k nim.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Ohledně toho, jak ručně zašifrovat také existující soubory, nahlédněte do dokumentace pro správce.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je poslední varování: Opravdu chcete zapnout šifrování?",
    "Failed to delete group \"{group}\"" : "Nepodařilo se vytvořit skupinu „{group}“",
    "Please confirm the group removal" : "Potvrďte odstranění skupiny",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Chystáte se smazat skupinu „{group}“. Účty k ní přiřazené nebudou smazány.",
    "Submit" : "Odeslat",
    "Rename group" : "Přejmenovat skupinu",
    "Delete group" : "Smazat skupinu",
    "Current password" : "Dosavadní heslo",
    "New password" : "Nové heslo",
    "Change password" : "Změnit heslo",
    "Choose your profile picture" : "Vyberte si svůj profilový obrázek",
    "Please select a valid png or jpg file" : "Vyberte platný png nebo jpg soubor",
    "Error setting profile picture" : "Chyba při nastavování profilového obrázku",
    "Error cropping profile picture" : "Chyba při ořezávání profilového obrázku",
    "Error saving profile picture" : "Chyba při ukládání profilového obrázku",
    "Error removing profile picture" : "Chyba při odebírání profilového obrázku",
    "Your profile picture" : "Váš profilový obrázek",
    "Upload profile picture" : "Nahrát profilový obrázek",
    "Choose profile picture from Files" : "Zvolit profilový obrázek ze Souborů",
    "Remove profile picture" : "Odebrat profilový obrázek",
    "The file must be a PNG or JPG" : "Je třeba, aby soubor by PNG nebo JPG",
    "Picture provided by original account" : "Obrázek poskytovaný původním účtem",
    "Set as profile picture" : "Nastavit jako profilový obrázek",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Mějte na paměti, že může trvat až 24 hodin, než bude váš profilový obrázek aktualizován všude.",
    "Your biography. Markdown is supported." : "Váš životopis. Jsou podporovány Markdown značky.",
    "Unable to update date of birth" : "Nedaří se aktualizovat datum narození",
    "Enter your date of birth" : "Zadejte datum svého narození",
    "You are using {s}{usage}{/s}" : "Využíváte {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Využíváte {s}{usage}{/s} z {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Jste členy následujících skupin:",
    "Your full name" : "Vaše celé jméno",
    "Email options" : "Předvolby pro e-mail",
    "Options for additional email address {index}" : "Volby pro dodatečnou e-mailovou adresu {index}",
    "Remove primary email" : "Odebrat hlavní e-mail",
    "Delete email" : "Smazat e-mail",
    "This address is not confirmed" : "Z této adresy jste ještě nepotvrdili ověřovací e-mail",
    "Unset as primary email" : "Zrušeno nastavení coby hlavního e-mailu",
    "Set as primary email" : "Nastavit jako hlavní e-mail",
    "Additional email address {index}" : "Další e-mailová adresa {index}",
    "Unable to delete primary email address" : "Nepodařilo se smazat hlavní e-mailovou adresu",
    "Unable to update primary email address" : "Nepodařilo se aktualizovat hlavní e-mailovou adresu",
    "Unable to add additional email address" : "Nepodařilo se přidat další e-mailovou adresu",
    "Unable to update additional email address" : "Nepodařilo se aktualizovat další e-mailovou adresu",
    "Unable to delete additional email address" : "Nepodařilo se smazat další e-mailovou adresu",
    "Primary email for password reset and notifications" : "Hlavní e-mail pro resetování hesla a oznamování",
    "No email address set" : "E-mailová adresa není nastavena",
    "Your handle" : "Váš identifikátor (handle)",
    "Derived from your locale ({weekDayName})" : "Odvozeno od místních a jazykových nastavení ({weekDayName})",
    "Unable to update first day of week" : "Nepodařilo se zaktualizovat nastavení prvního dne týdne",
    "Day to use as the first day of week" : "Den který používat jako první den týdne",
    "Your headline" : "Váš nadpis",
    "Unable to update language" : "Jazyk se nedaří aktualizovat",
    "Languages" : "Jazyky",
    "Help translate" : "Pomoci s překladem",
    "No language set" : "Není nastaven jazyk",
    "Unable to update locale" : "Nedaří se aktualizovat místní a jazyková nastavení",
    "Locales" : "Místní jazyková nastavení",
    "Week starts on {firstDayOfWeek}" : "Týden začíná {firstDayOfWeek}",
    "No locale set" : "Nenastaveno žádné místní a jazykové nastavení",
    "Your city" : "Město ve kterém/poblíž kterého žijete",
    "Your organisation" : "Vaše organizace",
    "Your phone number" : "Vlastní telefonní číslo",
    "Edit your Profile visibility" : "Upravit viditelnost profilu",
    "Unable to update profile enabled state" : "Nedaří se aktualizovat stav zapnutí profilu",
    "Enable profile" : "Zapnout profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Ohledně vašeho profilu bude respektována to více omezující nastavení – například, pokud je viditelnost nastavená na „Zobrazit všem“ a rozsah je nastavený na „Soukromé“, je respektováno „Soukromé.",
    "Unable to update visibility of {displayId}" : "Nedaří se aktualizovat viditelnost {displayId}",
    "she/her" : "ona/jí",
    "he/him" : "on/jemu",
    "they/them" : "oni/jim",
    "Your pronouns. E.g. {pronounsExample}" : "Vaše zájmena. Např. {pronounsExample}",
    "Your role" : "Vaše úloha",
    "Your X (formerly Twitter) handle" : "Vaše přezdívka na X (dříve Twitter)",
    "Your website" : "Vlastní webová stránka",
    "Invalid value" : "Neplatná hodnota",
    "Unable to update {property}" : "Nedaří se aktualizovat {property}",
    "No {property} set" : "Nenastaveno žádné {property}",
    "Change scope level of {property}, current scope is {scope}" : "Změnit stupeň rozsahu {property}, stávající je {scope}",
    "Unable to update federation scope of the primary {property}" : "Nedaří se aktualizovat rozsah federování primární {property}",
    "Unable to update federation scope of additional {property}" : "Nedaří se aktualizovat rozsah federování dodatečné {property}",
    "Add additional email" : "Přidat další e-mail",
    "Add" : "Přidat",
    "Create" : "Vytvářet",
    "Change" : "Změnit",
    "Delete" : "Smazat",
    "Reshare" : "Sdílet dál dalším",
    "Default language" : "Výchozí jazyk",
    "Common languages" : "Běžné jazyky",
    "Other languages" : "Ostatní jazyky",
    "Password change is disabled because the master key is disabled" : "Změna hesla je vypnutá protože je vypnutý hlavní klíč",
    "No accounts" : "Žádné účty",
    "Loading accounts …" : "Načítání účtů…",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Seznam účtů. Není vykreslen celý z důvodu nároků na výkon. Účty budou dokreslovány, jak se budete posouvat seznamem.",
    "Manager" : "Nástroj pro správu",
    "Set line manager" : "Nastavit přímého nadřízeného",
    "Account name will be autogenerated" : "Název účtu bude vytvořen automaticky",
    "Account name (required)" : "Název účtu (vyžadováno)",
    "Failed to search groups" : "Nepodařilo se prohledat skupiny",
    "New account" : "Nový účet",
    "Display name" : "Zobrazované jméno",
    "Either password or email is required" : "Je zapotřebí heslo nebo e-mail",
    "Password (required)" : "Heslo (vyžadováno)",
    "Email (required)" : "E-mail (vyžadováno)",
    "Email" : "E-mail",
    "Member of the following groups (required)" : "Člen následujících skupin (vyžadováno)",
    "Member of the following groups" : "Člen následujících skupin",
    "Set account groups" : "Nastavit skupiny účtu",
    "Admin of the following groups" : "Správce následujících skupin",
    "Set account as admin for …" : "Nastavit účet správce pro…",
    "Quota" : "Kvóta",
    "Set account quota" : "Nastavit kvótu pro účet",
    "Language" : "Jazyk",
    "Set default language" : "Nastavit výchozí jazyk",
    "Add new account" : "Přidat nový účet",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} účet …","{userCount} účty …","{userCount} účtů …","{userCount} účty …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} účet","{userCount} účty","{userCount} účtů","{userCount} účty"],
    "Total rows summary" : "Celkový souhrn řádek",
    "Scroll to load more rows" : "Další řádky načtete posunutím dolů",
    "Password or insufficient permissions message" : "Zpráva o heslu nebo nedostatečném oprávnění",
    "Avatar" : "Profilový obrázek",
    "Account name" : "Název účtu",
    "Group admin for" : "Správce skupiny",
    "Account backend" : "Podpůrná vrstva účtu",
    "Storage location" : "Úložiště dat",
    "First login" : "První přihlášení",
    "Last login" : "Poslední přihlášení",
    "Account actions" : "Akce ohledně účtu",
    "{size} used" : "{size} použito",
    "Delete account" : "Smazat účet",
    "Disconnect all devices and delete local data" : "Odpojit veškerá zařízení a smazat data na nich",
    "Disable account" : "Vypnout účet",
    "Enable account" : "Zapnout účet",
    "Resend welcome email" : "Znovu poslat uvítací e-mail",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "V případě ztráty zařízení, nebo např. odchodu z firmy, toto může vzdáleně vymazat Nextcloud data ze všech zařízení asociovaných s uživatelem {userid}. Funguje jen pokud se zařízení připojí k Internetu.",
    "Remote wipe of devices" : "Vymazat obsah zařízení na dálku",
    "Wipe {userid}'s devices" : "Vymazat obsah ze zařízení uživatele {userid}",
    "Wiped {userid}'s devices" : "Data ze zařízení uživatele {userid} vymazána",
    "Failed to load groups with details" : "Nepodařilo se načíst skupiny s podrobnostmi",
    "Failed to load sub admin groups with details" : "Nepodařilo se načíst skupiny dílčích správců s podrobnostmi",
    "Failed to update line manager" : "Nepodařilo se aktualizovat přímého nadřízeného",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Úplně vymazat účet {userid}, včetně veškerých osobní souborů, dat aplikací, atd.",
    "Account deletion" : "Smazání účtu",
    "Delete {userid}'s account" : "Smazat účet {userid}",
    "Display name was successfully changed" : "Zobrazené jméno bylo úspěšně změněno",
    "Password can't be empty" : "Heslo je třeba vyplnit",
    "Password was successfully changed" : "Heslo bylo úspěšně změněno",
    "Email can't be empty" : "E-mail je třeba vyplnit",
    "Email was successfully changed" : "E-mail byl úspěšně změněn",
    "Welcome mail sent!" : "Uvítací e-mail odeslán!",
    "Loading account …" : "Načítání účtu…",
    "Change display name" : "Změnit zobrazované jméno",
    "Set new password" : "Nastavit nové heslo",
    "You do not have permissions to see the details of this account" : "Nemáte oprávnění zobrazit si podrobností o tomto účtu",
    "Set new email address" : "Nastavit novou e-mailovou adresu",
    "Add account to group" : "Přidat účet do skupiny",
    "Set account as admin for" : "Nastavit účet coby správce pro",
    "Select account quota" : "Vyberte kvótu pro účet",
    "Set the language" : "Nastavit jazyk",
    "Toggle account actions menu" : "Vyp/zap. nabídku akcí účtu",
    "Done" : "Dokončeno",
    "Edit" : "Upravit",
    "Account management settings" : "Nastavení správy uživatelských účtů",
    "Visibility" : "Viditelnost",
    "Show language" : "Zobrazit jazyk",
    "Show account backend" : "Zobrazit podpůrnou vrstvu účtu",
    "Show storage path" : "Zobrazit popis umístění úložiště",
    "Show first login" : "Zobrazit první přihlášení",
    "Show last login" : "Zobrazit poslední přihlášení",
    "Sorting" : "Řazení",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Nastavení systému vynucuje řazení skupin podle názvu. Toto také vypíná zobrazování počtu členů.",
    "Group list sorting" : "Řazení seznamu skupin",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Z výkonnostních důvodů bude řazení uplatněno pouze na v tuto chvíli načtené skupiny. Ty budou načteny jak se budete pohybovat seznamem nebo ho prohledávat.",
    "By member count" : "Podle počtu členů",
    "By name" : "Podle názvu",
    "Send email" : "Odeslat e-mail",
    "Send welcome email to new accounts" : "Novým účtům posílat uvítací e-maily",
    "Defaults" : "Výchozí",
    "Default quota" : "Výchozí kvóta",
    "Select default quota" : "Vybrat výchozí kvótu",
    "Server error while trying to complete WebAuthn device registration" : "Chyba serveru při pokusu o dokončení registrace WebAuthn zařízení",
    "Passwordless authentication requires a secure connection." : "Ověřování se bez hesla vyžaduje zabezpečené připojení.",
    "Add WebAuthn device" : "Přidat WebAuthn zařízení",
    "Please authorize your WebAuthn device." : "Udělte pověření vámi využívanému WebAuthn zařízení.",
    "Adding your device …" : "Přidávání vašeho zařízení",
    "Unnamed device" : "Nepojmenované zařízení",
    "Passwordless Authentication" : "Ověřování se bez zadávání hesla",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavte svůj účet pro využívání ověřování se bez hesla pomocí standardu FIDO2.",
    "No devices configured." : "Není nastavené žádné zařízení.",
    "The following devices are configured for your account:" : "U svého účtu máte nastavená následující zařízení:",
    "Your browser does not support WebAuthn." : "Vámi používaný prohlížeč nepodporuje WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako správce můžete upravit chování sdílení. Více informací naleznete v dokumentaci.",
    "You need to enable the File sharing App." : "Je třeba zapnout aplikaci pro sdílení souborů.",
    "App Store" : "Katalog aplikací",
    "Loading app list" : "Načítání seznamu aplikací…",
    "Loading categories" : "Načítání kategorií…",
    "Developer documentation ↗" : "Dokumentace pro vývojáře ↗",
    "Version {version}, {license}-licensed" : "Verze {version}, {license}-licencováno",
    "Version {version}" : "Verze {version}",
    "All accounts" : "Veškeré účty",
    "Admins" : "Správci",
    "Account group: {group}" : "Skupina účtu: {group}",
    "Account management" : "Správa účtů",
    "Sending…" : "Odesílání…",
    "Email sent" : "E-mail odeslán",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Z výkonových důvodů, pokud zapnete šifrování na Nextcloud serveru, budou šifrovány pouze nové a změněné soubory.",
    "Location" : "Poloha",
    "Profile picture" : "Profilový obrázek",
    "About" : "O uživateli",
    "Date of birth" : "Datum narození",
    "Full name" : "Celé jméno",
    "Additional email" : "Další e-mail",
    "Fediverse (e.g. Mastodon)" : "Fediverse (např. Mastodon)",
    "Headline" : "Nadpis",
    "Organisation" : "Organizace",
    "Phone number" : "Telefonní číslo",
    "Pronouns" : "Zájmena",
    "Role" : "Role",
    "X (formerly Twitter)" : "X (dříve Twitter)",
    "Website" : "Webová stránka",
    "Profile visibility" : "Viditelnost profilu",
    "Locale" : "Místní a jazyková nastavení",
    "First day of week" : "První den v týdnu",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Není k dispozici, protože tato vlastnost je vyžadována pro  hlavní funkce, včetně sdílení souborů a pozvánek v kalendáři",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Není k dispozici protože pro váš účet bylo federování vypnuto. V případě dotazů se obraťte na svou správu",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Není k dispozici protože zveřejňování údajů o konkrétních účtech není vyhledávacímu serveru povoleno. Pokud máte jakékoli dotazy, obraťte se na správu",
    "Discover" : "Objevit",
    "Your apps" : "Vaše aplikace",
    "Active apps" : "Aktivní aplikace",
    "Disabled apps" : "Vypnuté aplikace",
    "Updates" : "Aktualizace",
    "App bundles" : "Sady aplikací",
    "Featured apps" : "Doporučené aplikace",
    "Supported apps" : "Podporované aplikace",
    "Show to everyone" : "Ukázat všem",
    "Show to logged in accounts only" : "Ukázat jen přihlášeným účtům",
    "Hide" : "Skrýt",
    "Manually installed apps cannot be updated" : "Ručně nainstalované aplikace není možné zaktualizovat",
    "{progress}% Deploying …" : "{progress}% nasazování…",
    "{progress}% Initializing …" : "{progress}% inicializace…",
    "Health checking" : "Kontrola stavu",
    "Deploy and Enable" : "Nasadit a zapnout",
    "Download and enable" : "Stáhnout a zapnout",
    "Disable" : "Vypnout",
    "Allow untested app" : "Umožnit nevyzkoušenou aplikaci",
    "The app will be downloaded from the App Store" : "Aplikace bude stažena z katalogu aplikací",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tato aplikace není označena jako kompatibilní s vámi používanou verzí Nexcloud. Pokud budete pokračovat, pořád budete moci aplikaci nainstalovat. Uvědomte si ale, že aplikace nemusí fungovat, jak je očekáváno.",
    "Unknown" : "Neznámé",
    "Never" : "Nikdy",
    "Could not register device: Network error" : "Zařízení se nepodařilo zaregistrovat: chyba sítě",
    "Could not register device: Probably already registered" : "Zařízení se nepodařilo zaregistrovat: už zaregistrováno",
    "Could not register device" : "Zařízení se nepodařilo zaregistrovat",
    "An error occurred during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
    "The app has been enabled but needs to be updated." : "Aplikace byla zapnuta, ale je třeba ji zaktualizovat.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla zapnuta ale je třeba ji ještě aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
    "Do you really want to wipe your data from this device?" : "Opravdu chcete vymazat svá data z tohoto zařízení?",
    "Confirm wipe" : "Potvrdit vymazání",
    "Could not delete the app token" : "Token aplikace se nepodařilo zkopírovat",
    "Error while wiping the device with the token" : "Chyba při vymazávání zařízení s tokenem",
    "Error while updating device token name" : "Chyba při aktualizaci názvu tokenu zařízení",
    "Error while updating device token scope" : "Chyba při aktualizaci rozsahu tokenu zařízení",
    "Could not set group sorting" : "Nepodařilo se nastavit řazení skupiny",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
    "Error" : "Chyba",
    "Account documentation" : "Dokumentace k účtům",
    "Administration documentation" : "Dokumentace ke správě",
    "Forum" : "Diskuzní fórum",
    "Nextcloud help & privacy resources" : "Nápověda k Nextcloud a prostředky k soukromí",
    "General documentation" : "Obecná dokumentace",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "None/STARTTLS" : "Žádné/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Otevřít dokumentaci",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Je důležité tento server nastavit, aby mohly být odesílány e-maily, jako jsou např. ty pro resetování hesla a s upozorněními.",
    "Send mode" : "Režim odesílání",
    "Encryption" : "Šifrování",
    "Sendmail mode" : "Režim sendmail",
    "From address" : "Adresa odesílatele",
    "Server address" : "Adresa serveru",
    "Port" : "Port",
    "Authentication" : "Ověřování se",
    "Authentication required" : "Vyžadováno ověření se",
    "Credentials" : "Přihlašovací údaje",
    "SMTP Login" : "SMPT přihlášení",
    "SMTP Password" : "Heslo pro SMTP",
    "Save" : "Uložit",
    "Test and verify email settings" : "Vyzkoušet a ověřit nastavení e-mailu",
    "Security & setup warnings" : "Varování ohledně zabezpečení a nastavení",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pro zabezpečení a optimální výkon instance Nextcloud je důležité, aby vše bylo správně nastaveno. Jako pomoc, instance samotná automaticky ověřuje některá nastavení. Další informace naleznete v odkazované dokumentaci.",
    "All checks passed." : "Všechny kontroly dopadly dobře.",
    "There are some errors regarding your setup." : "Jsou zde nějaké chyby ohledně vašeho nastavení.",
    "There are some warnings regarding your setup." : "Jsou zde nějaká varování ohledně vašeho nastavení.",
    "Checking for system and security issues." : "Kontrola systému a problémů se zabezpečením.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Důkladně si přečtěte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">průvodce instalací ↗</a> a zkontrolujte, že v <a href=\"%2$s\">záznamu událostí</a> nejsou žádné chyby ani varování.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Zkontrolujte zabezpečení svého Nextcloud přes <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">náš skener zabezpečení ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Důvody proč používat Nextcloud ve vaší organizaci",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Vyvíjeno {communityopen}komunitou Nextcloud{linkclose}, {githubopen}zdrojové kódy{linkclose} jsou licencovány pod {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Hodnoťte naše stránky na Facebooku",
    "Follow us on X" : "Sledujte nás na X",
    "Follow us on Mastodon" : "Následujte nás na Mastodon",
    "Check out our blog" : "Čtete náš blog",
    "Subscribe to our newsletter" : "Přihlaste se k odběru našeho zpravodaje",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Toto komunitní vydání Nextcloud není podporováno a okamžitá oznámení proto nejsou k dispozici",
    "Use a second factor besides your password to increase security for your account." : "Pro zlepšení zabezpečení vašeho účtu použijte vedle hesla také druhý faktor.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Pokud pro připojování se k Nextcloud používáte aplikace třetích stran, nezapomeňte před zapnutím ověřování druhým faktorem vytvořit pro jednotlivé aplikace jejich hesla.",
    "Logged in account must be a subadmin" : "Je třeba, aby přihlášený účet byl dílčím správcem",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Aby bylo možné možné povolit spuštění této kontroly je třeba zajistit, aby se webový server mohl připojit sám na sebe. Proto je třeba, aby bylo možné přeložit na IP adresu a připojit se k alespoň jedné z `trusted_domains` nebo `overwrite.cli.url`. Tento nezdar může být výsledkem neshody DNS na serveru nebo odchozího pravidla na bráně firewall.",
    "File locking" : "Zamykání souborů",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transakční zamykání souborů je vypnuto, což může vést k problémům při souběžném přístupu. Abyste se jim vyhnuli, zapněte v config.php volbu „filelocking.enabled“.",
    "The PHP memory limit is below the recommended value of %s." : "Limit paměti pro PHP je nastaven na níže než doporučenou hodnotu %s.",
    "for WebAuthn passwordless login" : "pro WebAuthn přihlášení bez hesla",
    "for WebAuthn passwordless login, and SFTP storage" : "pro WebAuthn přihlášení bez hesla a SFTP úložiště",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP hlavička `%1$s` neobsahuje `%2$s`. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zjištěna verze PostgreSQL „%s“. Pro nejlepší výkon, stabilitu a funkčnost s touto verzí Nextcloud je doporučeno PostgreSQL >=12 a <=16.",
    "Set default expiration date for shares" : "Nastavit výchozí datum skončení platnosti pro sdílení",
    "Your biography" : "Váš životopis",
    "You are using <strong>{usage}</strong>" : "Využíváte <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Využíváte <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Failed to load subadmin groups with details" : "Nepodařilo se načíst skupiny dílčích správců s podrobnostmi"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
